==> react-native-maps-0.13.0.tgz: package/CHANGELOG.md <==
# Change Log

## 0.13.0 (January 6, 2017)

### Breaking Changes

* Update iOS header imports and JS SyntheticEvent import for RN 0.40
  [#923](https://github.com/airbnb/react-native-maps/pull/923)
  (@ide)

### Patches

* Fix issue where callouts sometimes overlap or don't appear
  [#936](https://github.com/airbnb/react-native-maps/pull/936)
  (@RajkumarPunchh)

## 0.12.3 (January 6, 2017)

### Patches

* Fix "Animating with MapViews" example – fixes #763
  [#888](https://github.com/airbnb/react-native-maps/pull/888)
  (@javiercr)
* [iOS] Fix "Option 2" method of building Google Maps
  [#900](https://github.com/airbnb/react-native-maps/pull/900)
  (@vjeranc)
* [Android] Fix exception when animating region during initialization
  [#901](https://github.com/airbnb/react-native-maps/pull/901)
  (@mlanter)
* Updated documentation
  [#902](https://github.com/airbnb/react-native-maps/pull/902),
  [#904](https://github.com/airbnb/react-native-maps/pull/904),
  [#910](https://github.com/airbnb/react-native-maps/pull/910)
  (@anami, @dboydor, @ali-alamine)
*
  [#](https://github.com/airbnb/react-native-maps/pull/)
  (@)
*
  [#](https://github.com/airbnb/react-native-maps/pull/)
  (@)
*
  [#](https://github.com/airbnb/react-native-maps/pull/)
  (@)
*
  [#](https://github.com/airbnb/react-native-maps/pull/)
  (@)


## 0.12.2 (December 9, 2016)

### Patches

* [Android] Added support for taking snapshots on Android
  [#625](https://github.com/airbnb/react-native-maps/pull/625)
  (@IjzerenHein)
* [iOS] Allow legalLabelInsets to be changed and animated
  [#873](https://github.com/airbnb/react-native-maps/pull/873)
  (@scarlac)
* Added rotation attribute documentation
  [#871](https://github.com/airbnb/react-native-maps/pull/871)
  (@Arman92)
* Update mapview.md documentation
  [#866](https://github.com/airbnb/react-native-maps/pull/866)
  (@dccarmo)


## 0.12.1 (December 6, 2016)

This release only corrects the version in package.json.

## 0.12.0 (December 6, 2016)

NOTE: This version was not published because package.json was not properly updated

### Breaking Changes

* [android] If we've disabled scrolling within the map, then don't capture the touch events
  [#664](https://github.com/airbnb/react-native-maps/pull/664)
  (@mikelambert)
* [android] Use latest Google Play Services
  [#731](https://github.com/airbnb/react-native-maps/pull/731)
  (@mlanter)
* [android] update google play services
  [#805](https://github.com/airbnb/react-native-maps/pull/805)
  (@lrivera)

### Patches

* [iOS] Support iOS SDK < 10 ( XCode < 8 )
  [#708](https://github.com/airbnb/react-native-maps/pull/708)
  (@rops)
* [iOS] Added showsUserLocation property support for Google Maps
  [#721](https://github.com/airbnb/react-native-maps/pull/721)
  (@julien-rodrigues)
* [iOS] Added Google Maps Circle, Polygon, Polyline, MapType Support
  [#722](https://github.com/airbnb/react-native-maps/pull/722)
  (@unboundfire)
* [iOS] Fix Anchor point on Google Maps iOS
  [#734](https://github.com/airbnb/react-native-maps/pull/734)
  (@btoueg)
* [Google Maps iOS] Marker init with image props.
  [#738](https://github.com/airbnb/react-native-maps/pull/738)
  (@btoueg)
* [iOS] Fix dynamic imageSrc removal
  [#737](https://github.com/airbnb/react-native-maps/pull/737)
  (@btoueg)
* [iOS] implement fitToSuppliedMarkers and fitToCoordinates for google
  [#750](https://github.com/airbnb/react-native-maps/pull/750)
  (@gilbox)
* [iOS][android] Add onPress for polygons and polylines on iOS and Android
  [#760](https://github.com/airbnb/react-native-maps/pull/760)
  (@frankrowe)
* [iOS] Fix flicker of map pins on state change
  [#728](https://github.com/airbnb/react-native-maps/pull/728)
  (@mlanter)
* [iOS] Set region only when view has width&height
  [#785](https://github.com/airbnb/react-native-maps/pull/785)
  (@gilbox)
* [iOS] Implements animateToRegion for Google
  [#779](https://github.com/airbnb/react-native-maps/pull/779)
  (@btoueg)
* [iOS] Google Maps Custom Tile Support
  [#770](https://github.com/airbnb/react-native-maps/pull/770)
  (@unboundfire)
* [android] Map Styling for android
  [#808](https://github.com/airbnb/react-native-maps/pull/808)
  (@ali-alamine using @azt3k code)
* [iOS] IOS Google Map styling
  [#817](https://github.com/airbnb/react-native-maps/pull/817)
  (@ali-alamine using @azt3k code)
* [iOS] Add support for polygon holes for Apple Maps and Google Maps on iOS
  [#801](https://github.com/airbnb/react-native-maps/pull/801)
  (@therealgilles)
* [iOS] Fixes #470. Support legalLabelInsets on Apple Maps
  [#840](https://github.com/airbnb/react-native-maps/pull/840)
  (@scarlac)

## 0.11.0 (October 16, 2016)

NOTE: `0.10.4` was released *after* this version, and it's possible
`0.11.0` does not include everything in `0.10.4`. (see #851)

### Breaking Changes

* Update example app for RN 0.35, fix Gmaps bug for 0.35
  [#695](https://github.com/airbnb/react-native-maps/pull/695)
  (@spikebrehm)
* Upgraded to RN 0.35
  [#680](https://github.com/airbnb/react-native-maps/pull/680)
  (@eugenehp)

### Patches

* Update installation.md
  [#696](https://github.com/airbnb/react-native-maps/pull/696)
  (@securingsincity)
* [android] Fixes crash during Activity onPause()
  [#694](https://github.com/airbnb/react-native-maps/pull/694)
  (@felipecsl)
* Included MapUrlTile usage in README.md
  [#687](https://github.com/airbnb/react-native-maps/pull/687)
  (@ochanje210)
* [android] Add parameter to disable the moving on marker press
  [#676](https://github.com/airbnb/react-native-maps/pull/676)
  (@mlanter)
* Add support for setting zIndex on markers
  [#675](https://github.com/airbnb/react-native-maps/pull/675)
  (@mlanter)

## 0.10.4 (October 31, 2016)

### Patches

* [iOS] implement fitToSuppliedMarkers and fitToCoordinates for google maps
  [#750](https://github.com/airbnb/react-native-maps/pull/750)
  (@gilbox)
* [android] If we've disabled scrolling within the map, then don't capture the touch events
  [#664](https://github.com/airbnb/react-native-maps/pull/664)
  (@mikelambert)
* [iOS] Fix Anchor point on Google Maps iOS
  [#734](https://github.com/airbnb/react-native-maps/pull/734)
  (@btoueg)
* [iOS] Added showsUserLocation property support for Google Maps
  [#721](https://github.com/airbnb/react-native-maps/pull/721)
  (@julien-rodrigues)
* [iOS][android] Add support for setting zIndex on markers
  [#675](https://github.com/airbnb/react-native-maps/pull/675)
  (@mlanter)
* [android] Add parameter to disable the moving on marker press
  [#676](https://github.com/airbnb/react-native-maps/pull/676)
  (@mlanter)
* NOTE: v0.10.3 was not published

## 0.10.2 (October 19, 2016)

### Patches

* [android] Fixes crash during Activity onPause() (fixes #414)
  [#694](https://github.com/airbnb/react-native-maps/pull/694)
  (@felipecsl)

## 0.10.1 (October 10, 2016)

This release fixes issue [#656](https://github.com/airbnb/react-native-maps/issues/656)

### Patches

* [android] fix gradle build setup for explorer, bump to gradle 2.2.0
  [#666](https://github.com/airbnb/react-native-maps/pull/666)
  (@gilbox)
* [android] fix getAirMapName to fix ref-based commands
  [#665](https://github.com/airbnb/react-native-maps/pull/665)
  (@gilbox)

## 0.10.0 (October 5, 2016)

### Breaking Changes

* Upgrade to `react-native@0.33.0`

## 0.9.0 (September 28, 2016)

As of this release, this repository has moved from
`lelandrichardson/react-native-maps` to `airbnb/react-native-maps`.

### Breaking Changes

* [iOS] Support Google Maps on iOS
  [#548](https://github.com/airbnb/react-native-maps/pull/548)
  (@gilbox)

### Patches

* Added support for AnimatedRegion without modifying the AnimatedImplementation.js of react-native
  [#608](https://github.com/airbnb/react-native-maps/pull/608)
  (@IjzerenHein)
* [iOS] Remove pod stuff. Fix AirMaps.xcodeproj related to missing pod stuff
  [#620](https://github.com/airbnb/react-native-maps/pull/620)
  (@gilbox)
* [iOS] Fix import of AIRMapSnapshot
  [#622](https://github.com/airbnb/react-native-maps/pull/622)
  (@spikebrehm)
* [iOS] Fix nullability issue
  [#614](https://github.com/airbnb/react-native-maps/pull/614)
  (@simonmitchell)
* [iOS] Added support for drawing polylines on snapshots on iOS
  [#615](https://github.com/airbnb/react-native-maps/pull/615)
  (@IjzerenHein)
* Add `fitToCoordinates` method
  [#545](https://github.com/airbnb/react-native-maps/pull/545)
  (@naoufal)
* [Android] Fix list of examples on Android
  [#597](https://github.com/airbnb/react-native-maps/pull/597)
  (@spikebrehm)
* [Android] Fix overlapping map issue
  [#589](https://github.com/airbnb/react-native-maps/pull/589)
  (@fdnhkj)
* Add tile overlay support
  [#595](https://github.com/airbnb/react-native-maps/pull/595)
  (@cascadian, @spikebrehm)
* [Android] Support Android LiteMode
  [#546](https://github.com/airbnb/react-native-maps/pull/546)
  (@rops)
* s/lelandrichardson/airbnb/
  [#573](https://github.com/airbnb/react-native-maps/pull/573)
  (@spikebrehm)
* [Android] Don't fit to elements if no positions added
  [#567](https://github.com/airbnb/react-native-maps/pull/567)
  (@ryankask)
* [iOS] Add class prefix to EmptyCalloutBackgroundView
  [#563](https://github.com/airbnb/react-native-maps/pull/563)
  (@terribleben)
* [Android] Minor code cleanup
  [#564](https://github.com/airbnb/react-native-maps/pull/564)
  (@felipecsl)
* Documentation updates
  [#566](https://github.com/airbnb/react-native-maps/pull/566),
  [#591](https://github.com/airbnb/react-native-maps/pull/591),
  [#601](https://github.com/airbnb/react-native-maps/pull/601),
  [#602](https://github.com/airbnb/react-native-maps/pull/602),
  [#624](https://github.com/airbnb/react-native-maps/pull/624)
  (@felipecsl, @Alastairm, @Keksike, @bbodenmiller)

## 0.8.2 (September 8, 2016)

We realized immediately after publishing 0.8.1 that the NPM package contained
some test code in the `example2/` directory that contained a copy of the
`react-native` package, causing this packager error:

```
Failed to build DependencyGraph: @providesModule naming collision:
  Duplicate module name: String.prototype.es6
  Paths: /Users/<path to project>/node_modules/react-native-maps/example2/node_modules/react-native/packager/react-packager/src/Resolver/polyfills/String.prototype.es6.js collides with /Users/<path to project>/node_modules/react-native/packager/react-packager/src/Resolver/polyfills/String.prototype.es6.js

This error is caused by a @providesModule declaration with the same name accross two different files.
```

0.8.2 is identical to 0.8.1, except with the offending code removed from the NPM package.


## 0.8.1 (September 8, 2016) *[DEPRECATED]*

#### *NOTE: 0.8.1 has been unpublished from NPM because it was faulty. Please use 0.8.2.*

### Patches

- [Android] Use latest available (wildcard version) of RN to build Android ([PR #547](https://github.com/airbnb/react-native-maps/pull/547))
- [Android] Use `Activity` to call `MapsInitialier.initialize()` ([PR #449](https://github.com/airbnb/react-native-maps/pull/449))
- [Android] Fix file path for `AirMapModule` ([PR #526](https://github.com/airbnb/react-native-maps/pull/526))
- [Android] Fix path to React Native in `node_modules` ([PR #527](https://github.com/airbnb/react-native-maps/pull/527))
- [Android] Bump Google Play Services dependency to `9.4.0` ([PR #533](https://github.com/airbnb/react-native-maps/pull/533))
- [iOS] Fix a few warnings ([PR #534](https://github.com/airbnb/react-native-maps/pull/534))
- [JS] Fix ESLint violations ([PR #515](https://github.com/airbnb/react-native-maps/pull/515))

## 0.8.0 (August 30, 2016)

### Breaking Changes

- Upgrade to `react-native@0.32.0`, and update Android code to match ([#502](https://github.com/airbnb/react-native-maps/pull/502))

### Patches

- [android] Add `showsMyLocationButton` prop ([#382](https://github.com/airbnb/react-native-maps/pull/382))

- Add `fitToSuppliedMarkers()` method ([#386](https://github.com/airbnb/react-native-maps/pull/386))

- [ios] Update AirMapMarker to use loadImageWithURLRequest ([#389](https://github.com/airbnb/react-native-maps/pull/389))

- Improvements to watch and copy script ([#445](https://github.com/airbnb/react-native-maps/pull/445))

- [ios] Added check on marker class in predicate ([#485](https://github.com/airbnb/react-native-maps/pull/485))

- Use `StyleSheet.absoluteFillObject` where appropriate ([#500](https://github.com/airbnb/react-native-maps/pull/500)) and ([#493](https://github.com/airbnb/react-native-maps/pull/493))

- Add ESLint and fix a number of linting violations ([#501](https://github.com/airbnb/react-native-maps/pull/501))

- Remove unused `NativeMethodsMixin` for compat with RN 0.32 ([#511](https://github.com/airbnb/react-native-maps/pull/511))


## 0.7.1 (July 9, 2016)

### Patches

- Fix iOS CocoaPods Issue ([#308](https://github.com/airbnb/react-native-maps/pull/308))



## 0.7.0 (July 9, 2016)

### Breaking Changes

- RN 0.29 compatibility changes ([#363](https://github.com/airbnb/react-native-maps/pull/363) and [#370](https://github.com/airbnb/react-native-maps/pull/370))


### Patches

- Fixing scrolling map inside a scrollView ([#343](https://github.com/airbnb/react-native-maps/pull/343))

- Fix shouldUsePinView ([#344](https://github.com/airbnb/react-native-maps/pull/344))

- Not calling setLoadingIndicatorColor when null ([#337](https://github.com/airbnb/react-native-maps/pull/337))

- Fixes `Undefined symbols for architecture x86_64: “std::terminate()”` ([#329](https://github.com/airbnb/react-native-maps/pull/329))



## 0.6.0

## 0.5.0

* [Android] Updated package to `com.airbnb.android.react.maps` (PR #225)
* [Android] Lint fixes (PR #232)

## 0.4.0

 * Initial release

==> react-native-maps-0.15.0.tgz: package/CHANGELOG.md <==
# Change Log

## 0.14.0 (April 4, 2017)

## Enhancements

* Restructure project #1164

* Add showsIndoorLevelPicker -> setIndoorLevelPickerEnabled to MapView #1019
[#1188](https://github.com/airbnb/react-native-maps/pull/1188)

* iOS - Added onPress support for Polygons on Google Maps
[#1024](https://github.com/airbnb/react-native-maps/pull/1024)

*  Add customized user location annotation text
[#1049](https://github.com/airbnb/react-native-maps/pull/1049)

* iOS - Google Maps - Add `showsMyLocationButton` support
[#1157](https://github.com/airbnb/react-native-maps/pull/1157)


## Patches

* Fix getResources() null crash in mapview
[#1188](https://github.com/airbnb/react-native-maps/pull/1188)

* Rename MapKit category to avoid conflicts with the one in RN
[#1172](https://github.com/airbnb/react-native-maps/pull/1172)

* Upgrade GMS dependencies to 10.2.0
[#1169](https://github.com/airbnb/react-native-maps/pull/1169)

* fix multiple-instance memory leak
[#1130](https://github.com/airbnb/react-native-maps/pull/1130)

* fix onSelected event for markers with custom view
[#1079](https://github.com/airbnb/react-native-maps/pull/1079)

* Crash in our App fix
[#1096](https://github.com/airbnb/react-native-maps/pull/1096)

* Use local RCTConvert+MapKit instead of the one in React Native
[#1138](https://github.com/airbnb/react-native-maps/pull/1138)


## 0.13.1 (March 21, 2017)


## Enhancements

* Add id identifier to marker-press event on Android
[#1008](https://github.com/airbnb/react-native-maps/pull/1008)
  (@stan229)

* setNativeProps, marker opacity, nested components
[#940](https://github.com/airbnb/react-native-maps/pull/940)
  (@unboundfire)


## Patches

* Update the android buildToolsVersion to 25.0.0
[#1152](https://github.com/airbnb/react-native-maps/pull/1152)
  (@markusguenther)

* use `provided` for RN gradle dependency
[#1151](https://github.com/airbnb/react-native-maps/pull/1151)
  (@gpeal)

* fix null activity crash
[#1150](https://github.com/airbnb/react-native-maps/pull/1150)
  (@lelandrichardson)

* Updated Google play services and gradle build plugin
[#1023](https://github.com/airbnb/react-native-maps/pull/1023)
  (@chris-at-translate)

* Sets the map value for the AirMapUrlTile so that it can be updated properly
[#992](https://github.com/airbnb/react-native-maps/pull/992)
  (@jschloer)

* onPress and onCalloutPress doesn't trigger on markers in iOS
[#954](https://github.com/airbnb/react-native-maps/pull/954)
  (@RajkumarPunchh)



## 0.13.0 (January 6, 2017)

### Breaking Changes

* Update iOS header imports and JS SyntheticEvent import for RN 0.40
  [#923](https://github.com/airbnb/react-native-maps/pull/923)
  (@ide)

### Patches

* Fix issue where callouts sometimes overlap or don't appear
  [#936](https://github.com/airbnb/react-native-maps/pull/936)
  (@RajkumarPunchh)

## 0.12.3 (January 6, 2017)

### Patches

* Fix "Animating with MapViews" example – fixes #763
  [#888](https://github.com/airbnb/react-native-maps/pull/888)
  (@javiercr)
* [iOS] Fix "Option 2" method of building Google Maps
  [#900](https://github.com/airbnb/react-native-maps/pull/900)
  (@vjeranc)
* [Android] Fix exception when animating region during initialization
  [#901](https://github.com/airbnb/react-native-maps/pull/901)
  (@mlanter)
* Updated documentation
  [#902](https://github.com/airbnb/react-native-maps/pull/902),
  [#904](https://github.com/airbnb/react-native-maps/pull/904),
  [#910](https://github.com/airbnb/react-native-maps/pull/910)
  (@anami, @dboydor, @ali-alamine)


## 0.12.2 (December 9, 2016)

### Patches

* [Android] Added support for taking snapshots on Android
  [#625](https://github.com/airbnb/react-native-maps/pull/625)
  (@IjzerenHein)
* [iOS] Allow legalLabelInsets to be changed and animated
  [#873](https://github.com/airbnb/react-native-maps/pull/873)
  (@scarlac)
* Added rotation attribute documentation
  [#871](https://github.com/airbnb/react-native-maps/pull/871)
  (@Arman92)
* Update mapview.md documentation
  [#866](https://github.com/airbnb/react-native-maps/pull/866)
  (@dccarmo)


## 0.12.1 (December 6, 2016)

This release only corrects the version in package.json.

## 0.12.0 (December 6, 2016)

NOTE: This version was not published because package.json was not properly updated

### Breaking Changes

* [android] If we've disabled scrolling within the map, then don't capture the touch events
  [#664](https://github.com/airbnb/react-native-maps/pull/664)
  (@mikelambert)
* [android] Use latest Google Play Services
  [#731](https://github.com/airbnb/react-native-maps/pull/731)
  (@mlanter)
* [android] update google play services
  [#805](https://github.com/airbnb/react-native-maps/pull/805)
  (@lrivera)

### Patches

* [iOS] Support iOS SDK < 10 ( XCode < 8 )
  [#708](https://github.com/airbnb/react-native-maps/pull/708)
  (@rops)
* [iOS] Added showsUserLocation property support for Google Maps
  [#721](https://github.com/airbnb/react-native-maps/pull/721)
  (@julien-rodrigues)
* [iOS] Added Google Maps Circle, Polygon, Polyline, MapType Support
  [#722](https://github.com/airbnb/react-native-maps/pull/722)
  (@unboundfire)
* [iOS] Fix Anchor point on Google Maps iOS
  [#734](https://github.com/airbnb/react-native-maps/pull/734)
  (@btoueg)
* [Google Maps iOS] Marker init with image props.
  [#738](https://github.com/airbnb/react-native-maps/pull/738)
  (@btoueg)
* [iOS] Fix dynamic imageSrc removal
  [#737](https://github.com/airbnb/react-native-maps/pull/737)
  (@btoueg)
* [iOS] implement fitToSuppliedMarkers and fitToCoordinates for google
  [#750](https://github.com/airbnb/react-native-maps/pull/750)
  (@gilbox)
* [iOS][android] Add onPress for polygons and polylines on iOS and Android
  [#760](https://github.com/airbnb/react-native-maps/pull/760)
  (@frankrowe)
* [iOS] Fix flicker of map pins on state change
  [#728](https://github.com/airbnb/react-native-maps/pull/728)
  (@mlanter)
* [iOS] Set region only when view has width&height
  [#785](https://github.com/airbnb/react-native-maps/pull/785)
  (@gilbox)
* [iOS] Implements animateToRegion for Google
  [#779](https://github.com/airbnb/react-native-maps/pull/779)
  (@btoueg)
* [iOS] Google Maps Custom Tile Support
  [#770](https://github.com/airbnb/react-native-maps/pull/770)
  (@unboundfire)
* [android] Map Styling for android
  [#808](https://github.com/airbnb/react-native-maps/pull/808)
  (@ali-alamine using @azt3k code)
* [iOS] IOS Google Map styling
  [#817](https://github.com/airbnb/react-native-maps/pull/817)
  (@ali-alamine using @azt3k code)
* [iOS] Add support for polygon holes for Apple Maps and Google Maps on iOS
  [#801](https://github.com/airbnb/react-native-maps/pull/801)
  (@therealgilles)
* [iOS] Fixes #470. Support legalLabelInsets on Apple Maps
  [#840](https://github.com/airbnb/react-native-maps/pull/840)
  (@scarlac)

## 0.11.0 (October 16, 2016)

NOTE: `0.10.4` was released *after* this version, and it's possible
`0.11.0` does not include everything in `0.10.4`. (see #851)

### Breaking Changes

* Update example app for RN 0.35, fix Gmaps bug for 0.35
  [#695](https://github.com/airbnb/react-native-maps/pull/695)
  (@spikebrehm)
* Upgraded to RN 0.35
  [#680](https://github.com/airbnb/react-native-maps/pull/680)
  (@eugenehp)

### Patches

* Update installation.md
  [#696](https://github.com/airbnb/react-native-maps/pull/696)
  (@securingsincity)
* [android] Fixes crash during Activity onPause()
  [#694](https://github.com/airbnb/react-native-maps/pull/694)
  (@felipecsl)
* Included MapUrlTile usage in README.md
  [#687](https://github.com/airbnb/react-native-maps/pull/687)
  (@ochanje210)
* [android] Add parameter to disable the moving on marker press
  [#676](https://github.com/airbnb/react-native-maps/pull/676)
  (@mlanter)
* Add support for setting zIndex on markers
  [#675](https://github.com/airbnb/react-native-maps/pull/675)
  (@mlanter)

## 0.10.4 (October 31, 2016)

### Patches

* [iOS] implement fitToSuppliedMarkers and fitToCoordinates for google maps
  [#750](https://github.com/airbnb/react-native-maps/pull/750)
  (@gilbox)
* [android] If we've disabled scrolling within the map, then don't capture the touch events
  [#664](https://github.com/airbnb/react-native-maps/pull/664)
  (@mikelambert)
* [iOS] Fix Anchor point on Google Maps iOS
  [#734](https://github.com/airbnb/react-native-maps/pull/734)
  (@btoueg)
* [iOS] Added showsUserLocation property support for Google Maps
  [#721](https://github.com/airbnb/react-native-maps/pull/721)
  (@julien-rodrigues)
* [iOS][android] Add support for setting zIndex on markers
  [#675](https://github.com/airbnb/react-native-maps/pull/675)
  (@mlanter)
* [android] Add parameter to disable the moving on marker press
  [#676](https://github.com/airbnb/react-native-maps/pull/676)
  (@mlanter)
* NOTE: v0.10.3 was not published

## 0.10.2 (October 19, 2016)

### Patches

* [android] Fixes crash during Activity onPause() (fixes #414)
  [#694](https://github.com/airbnb/react-native-maps/pull/694)
  (@felipecsl)

## 0.10.1 (October 10, 2016)

This release fixes issue [#656](https://github.com/airbnb/react-native-maps/issues/656)

### Patches

* [android] fix gradle build setup for explorer, bump to gradle 2.2.0
  [#666](https://github.com/airbnb/react-native-maps/pull/666)
  (@gilbox)
* [android] fix getAirMapName to fix ref-based commands
  [#665](https://github.com/airbnb/react-native-maps/pull/665)
  (@gilbox)

## 0.10.0 (October 5, 2016)

### Breaking Changes

* Upgrade to `react-native@0.33.0`

## 0.9.0 (September 28, 2016)

As of this release, this repository has moved from
`lelandrichardson/react-native-maps` to `airbnb/react-native-maps`.

### Breaking Changes

* [iOS] Support Google Maps on iOS
  [#548](https://github.com/airbnb/react-native-maps/pull/548)
  (@gilbox)

### Patches

* Added support for AnimatedRegion without modifying the AnimatedImplementation.js of react-native
  [#608](https://github.com/airbnb/react-native-maps/pull/608)
  (@IjzerenHein)
* [iOS] Remove pod stuff. Fix AirMaps.xcodeproj related to missing pod stuff
  [#620](https://github.com/airbnb/react-native-maps/pull/620)
  (@gilbox)
* [iOS] Fix import of AIRMapSnapshot
  [#622](https://github.com/airbnb/react-native-maps/pull/622)
  (@spikebrehm)
* [iOS] Fix nullability issue
  [#614](https://github.com/airbnb/react-native-maps/pull/614)
  (@simonmitchell)
* [iOS] Added support for drawing polylines on snapshots on iOS
  [#615](https://github.com/airbnb/react-native-maps/pull/615)
  (@IjzerenHein)
* Add `fitToCoordinates` method
  [#545](https://github.com/airbnb/react-native-maps/pull/545)
  (@naoufal)
* [Android] Fix list of examples on Android
  [#597](https://github.com/airbnb/react-native-maps/pull/597)
  (@spikebrehm)
* [Android] Fix overlapping map issue
  [#589](https://github.com/airbnb/react-native-maps/pull/589)
  (@fdnhkj)
* Add tile overlay support
  [#595](https://github.com/airbnb/react-native-maps/pull/595)
  (@cascadian, @spikebrehm)
* [Android] Support Android LiteMode
  [#546](https://github.com/airbnb/react-native-maps/pull/546)
  (@rops)
* s/lelandrichardson/airbnb/
  [#573](https://github.com/airbnb/react-native-maps/pull/573)
  (@spikebrehm)
* [Android] Don't fit to elements if no positions added
  [#567](https://github.com/airbnb/react-native-maps/pull/567)
  (@ryankask)
* [iOS] Add class prefix to EmptyCalloutBackgroundView
  [#563](https://github.com/airbnb/react-native-maps/pull/563)
  (@terribleben)
* [Android] Minor code cleanup
  [#564](https://github.com/airbnb/react-native-maps/pull/564)
  (@felipecsl)
* Documentation updates
  [#566](https://github.com/airbnb/react-native-maps/pull/566),
  [#591](https://github.com/airbnb/react-native-maps/pull/591),
  [#601](https://github.com/airbnb/react-native-maps/pull/601),
  [#602](https://github.com/airbnb/react-native-maps/pull/602),
  [#624](https://github.com/airbnb/react-native-maps/pull/624)
  (@felipecsl, @Alastairm, @Keksike, @bbodenmiller)

## 0.8.2 (September 8, 2016)

We realized immediately after publishing 0.8.1 that the NPM package contained
some test code in the `example2/` directory that contained a copy of the
`react-native` package, causing this packager error:

```
Failed to build DependencyGraph: @providesModule naming collision:
  Duplicate module name: String.prototype.es6
  Paths: /Users/<path to project>/node_modules/react-native-maps/example2/node_modules/react-native/packager/react-packager/src/Resolver/polyfills/String.prototype.es6.js collides with /Users/<path to project>/node_modules/react-native/packager/react-packager/src/Resolver/polyfills/String.prototype.es6.js

This error is caused by a @providesModule declaration with the same name across two different files.
```

0.8.2 is identical to 0.8.1, except with the offending code removed from the NPM package.


## 0.8.1 (September 8, 2016) *[DEPRECATED]*

#### *NOTE: 0.8.1 has been unpublished from NPM because it was faulty. Please use 0.8.2.*

### Patches

- [Android] Use latest available (wildcard version) of RN to build Android ([PR #547](https://github.com/airbnb/react-native-maps/pull/547))
- [Android] Use `Activity` to call `MapsInitialier.initialize()` ([PR #449](https://github.com/airbnb/react-native-maps/pull/449))
- [Android] Fix file path for `AirMapModule` ([PR #526](https://github.com/airbnb/react-native-maps/pull/526))
- [Android] Fix path to React Native in `node_modules` ([PR #527](https://github.com/airbnb/react-native-maps/pull/527))
- [Android] Bump Google Play Services dependency to `9.4.0` ([PR #533](https://github.com/airbnb/react-native-maps/pull/533))
- [iOS] Fix a few warnings ([PR #534](https://github.com/airbnb/react-native-maps/pull/534))
- [JS] Fix ESLint violations ([PR #515](https://github.com/airbnb/react-native-maps/pull/515))

## 0.8.0 (August 30, 2016)

### Breaking Changes

- Upgrade to `react-native@0.32.0`, and update Android code to match ([#502](https://github.com/airbnb/react-native-maps/pull/502))

### Patches

- [android] Add `showsMyLocationButton` prop ([#382](https://github.com/airbnb/react-native-maps/pull/382))

- Add `fitToSuppliedMarkers()` method ([#386](https://github.com/airbnb/react-native-maps/pull/386))

- [ios] Update AirMapMarker to use loadImageWithURLRequest ([#389](https://github.com/airbnb/react-native-maps/pull/389))

- Improvements to watch and copy script ([#445](https://github.com/airbnb/react-native-maps/pull/445))

- [ios] Added check on marker class in predicate ([#485](https://github.com/airbnb/react-native-maps/pull/485))

- Use `StyleSheet.absoluteFillObject` where appropriate ([#500](https://github.com/airbnb/react-native-maps/pull/500)) and ([#493](https://github.com/airbnb/react-native-maps/pull/493))

- Add ESLint and fix a number of linting violations ([#501](https://github.com/airbnb/react-native-maps/pull/501))

- Remove unused `NativeMethodsMixin` for compat with RN 0.32 ([#511](https://github.com/airbnb/react-native-maps/pull/511))


## 0.7.1 (July 9, 2016)

### Patches

- Fix iOS CocoaPods Issue ([#308](https://github.com/airbnb/react-native-maps/pull/308))



## 0.7.0 (July 9, 2016)

### Breaking Changes

- RN 0.29 compatibility changes ([#363](https://github.com/airbnb/react-native-maps/pull/363) and [#370](https://github.com/airbnb/react-native-maps/pull/370))


### Patches

- Fixing scrolling map inside a scrollView ([#343](https://github.com/airbnb/react-native-maps/pull/343))

- Fix shouldUsePinView ([#344](https://github.com/airbnb/react-native-maps/pull/344))

- Not calling setLoadingIndicatorColor when null ([#337](https://github.com/airbnb/react-native-maps/pull/337))

- Fixes `Undefined symbols for architecture x86_64: “std::terminate()”` ([#329](https://github.com/airbnb/react-native-maps/pull/329))



## 0.6.0

## 0.5.0

* [Android] Updated package to `com.airbnb.android.react.maps` (PR #225)
* [Android] Lint fixes (PR #232)

## 0.4.0

 * Initial release
